import * as api from './api';
import { UserPageQuery, AddReq, DelReq, EditReq, CreateCrudOptionsProps, CreateCrudOptionsRet, dict } from '@fast-crud/fast-crud';
import { commonCrudConfig } from "/@/utils/commonCrud";

export const createCrudOptions = function ({ crudExpose }: CreateCrudOptionsProps): CreateCrudOptionsRet {
	const pageRequest = async (query: UserPageQuery) => {
		return await api.GetList(query);
	};
	const editRequest = async ({ form, row }: EditReq) => {
		form.id = row.id;
		return await api.UpdateObj(form);
	};
	const delRequest = async ({ row }: DelReq) => {
		return await api.DelObj(row.id);
	};
	const addRequest = async ({ form }: AddReq) => {
		return await api.AddObj(form);
	};

	return {
		crudOptions: {
			request: {
				pageRequest,
				addRequest,
				editRequest,
				delRequest
			},
			columns: {
				_index: {
					title: '序号',
					form: { show: false },
					column: {
						align: 'center',
						width: '70px',
						columnSetDisabled: true,
						formatter: (context) => {
							let index = context.index ?? 1;
							let pagination = crudExpose!.crudBinding.value.pagination;
							return ((pagination!.currentPage ?? 1) - 1) * pagination!.pageSize + index + 1;
						}
					}
				},
				name: {
					title: '设备名称',
					search: { show: true },
					type: 'input',
					column: { minWidth: 120 },
					form: {
						component: { placeholder: '请输入设备名称' },
						rules: [{ required: true, message: '请输入设备名称' }]
					}
				},
				code: {
					title: '设备编号',
					search: { show: true },
					type: 'input',
					column: { minWidth: 120 },
					form: {
						component: { placeholder: '请输入设备编号' },
						rules: [{ required: true, message: '请输入设备编号' }]
					}
				},
				category_name: {
					title: '设备分类',
					search: { show: false },
					type: 'input',
					column: { minWidth: 100 }
				},
				specification: {
					title: '规格型号',
					search: { show: false },
					type: 'input',
					column: { minWidth: 100 },
					form: {
						component: { placeholder: '请输入规格型号' }
					}
				},
				status: {
					title: '设备状态',
					type: 'dict-select',
					search: { show: true },
					dict: dict({
						data: [
							{ label: '正常', value: 1 },
							{ label: '故障', value: 2 },
							{ label: '维修中', value: 3 },
							{ label: '报废', value: 4 }
						]
					}),
					column: { minWidth: 100 },
					form: {
						component: { placeholder: '请选择设备状态' },
						rules: [{ required: true, message: '请选择设备状态' }]
					}
				},
				location: {
					title: '存放位置',
					search: { show: true },
					type: 'input',
					column: { minWidth: 120 },
					form: {
						component: { placeholder: '请输入存放位置' }
					}
				},
				purchase_date: {
					title: '购买日期',
					type: 'date',
					search: { show: false },
					column: { minWidth: 120 },
					form: {
						component: { placeholder: '请选择购买日期' }
					}
				},
				price: {
					title: '设备价格',
					type: 'number',
					search: { show: false },
					column: { minWidth: 100 },
					form: {
						component: { placeholder: '请输入设备价格' }
					}
				},
				supplier: {
					title: '供应商',
					type: 'input',
					search: { show: false },
					column: { minWidth: 120 },
					form: {
						component: { placeholder: '请输入供应商' }
					}
				},
				maintenance_cycle: {
					title: '维护周期(天)',
					type: 'number',
					search: { show: false },
					column: { minWidth: 120 },
					form: {
						component: { placeholder: '请输入维护周期' }
					}
				},
				last_maintenance: {
					title: '上次维护时间',
					type: 'datetime',
					search: { show: false },
					column: { minWidth: 160 },
					form: { show: false }
				},
				remark: {
					title: '备注',
					type: 'text',
					search: { show: false },
					column: { minWidth: 120 },
					form: {
						component: { placeholder: '请输入备注信息' }
					}
				},
				...commonCrudConfig({
					create_datetime: { search: true },
					update_datetime: { search: true }
				})
			}
		}
	};
};